import requests
from bs4 import BeautifulSoup
import os

# the URL of the webpage to scrape
base_url = "https://pds-imaging.jpl.nasa.gov/data/mars2020/mars2020_mastcamz_ops_raw/data/sol/00466/ids/edr/zcam/"
download_folder = "images"

try:
    # create jpgs directory if it does not exist
    os.makedirs(download_folder, exist_ok=True)

    # exctract links from the page 
    response = requests.get(base_url)
    soup = BeautifulSoup(response.content, 'html.parser')    
    links = soup.find_all('a')
    
    last_link = "" # link of the last downloaded file
    # download any file with "EBY" and ("ZL0" or "ZR0") in its name 
    for link in links:
    
        href = link.get('href')        
        if href and ("EBY" in href) and (("ZL0" in href) or ("ZR0" in href)) and (href != last_link):
        
            last_link = href 
            
            url = base_url + href            
            file_name = os.path.join(download_folder, href)
            response = requests.get(url)
            
            with open(file_name, "wb") as f:
                f.write(response.content)
                print(f"Downloaded file: {file_name}")

except requests.exceptions.RequestException as e:
    print(f"An error occurred during the request: {e}")
except Exception as e:
    print(f"An error occurred: {e}")
