import os
import piexif

def add_exif_metadata(image_path):
    try:
        filename = os.path.basename(image_path)
        
        focal_length_str = filename.split("_")[-1][:3] # extract first 3 digits after last underscore
        focal_length = int(focal_length_str)
        
        exif_dict = {"0th": {}, "Exif": {}, "GPS": {}, "1st": {}}
        exif_dict["0th"][piexif.ImageIFD.Make] = "Malin Space Science Systems".encode()
        exif_dict["0th"][piexif.ImageIFD.Model] = "MastcamZ".encode()
        exif_dict["Exif"][piexif.ExifIFD.FocalLength] = (focal_length, 1)
        exif_bytes = piexif.dump(exif_dict)
        piexif.insert(exif_bytes, image_path)
        print(f"Adding EXIF entry for camera model: MastcamZ, Focal length: {focal_length}mm")
        
    except (AttributeError, piexif._exceptions.InvalidImageDataError):
        print(f"Skipping {image_path}. Not a valid image.")

# name of the subfolders containing the images

subfolder_name = "_geometry"

subfolder_path = os.path.join(os.getcwd(), subfolder_name)

for filename in os.listdir(subfolder_path):

    if filename.endswith(".jpg"):
        image_path = os.path.join(subfolder_path, filename)
        add_exif_metadata(image_path)
